@@ -85,7 +85,7 @@ class MainBaseHandler(tornado.web.RequestHandler):
         # TODO: add some logging here
         # TODO: if in debug mode, raise all exceptions
 
-        return self._respond((code, response))
+        return self._respond((code, response), error=True)
 
 
     ##################################################
@@ -176,7 +176,7 @@ class MainBaseHandler(tornado.web.RequestHandler):
 
         self._respond(response)
 
-    def _respond(self, response):
+    def _respond(self, response, error=False):
         pass
 
     def _parse_query(self):
@@ -256,7 +256,7 @@ class WebBaseHandler(MainBaseHandler):
     def css(self):
         return self._css
 
-    def _respond(self, response):
+    def _respond(self, response, error=False):
         if self._redirect:
             return tornado.web.RequestHandler.redirect(self, *self._redirect)
 
@@ -312,7 +312,7 @@ class ApiBaseHandler(MainBaseHandler):
         self._error = True
         raise ApiError(code, message)
 
-    def _respond(self, response):
+    def _respond(self, response, error=False):
         if self._redirect:
             response = dict(redirect=self._redirect[0])
 
@@ -322,8 +322,11 @@ class ApiBaseHandler(MainBaseHandler):
 
         response = dict(
             code=status_code,
-            time=int(time.time()),
-            response=content)
+            time=int(time.time()))
+        if error:
+            response['error'] = content
+        else:
+            response['response'] = content
 
         self.set_status(response['code'])
         self.write(xjson.dumps(response))
