@@ -36,6 +36,8 @@ class CLO(object):
                           help="port to run the server on")
         self.parser.add_option("-d", "--debug", action="store_true", dest="debug",
                           help="run the server in debug mode")
+        self.parser.add_option('-t', '--time-out', dest="timeout", default=5, type="int",
+                            help="Time to wait when stopping the server")
 
     def add_option(self, *args, **kawrgs):
         self.parser.add_option(*args, **kwargs)
@@ -44,9 +46,10 @@ class CLO(object):
         (self.options, self.args) = self.parser.parse_args()
 
 class Dorothy(object):
-    def __init__(self, routes=None, prelaunch=None, **kwargs):
+    def __init__(self, routes=None, prelaunch=None, shutdown=None, **kwargs):
         self._routes = routes
         self._prelaunch = prelaunch
+        self._shutdown_cb = shutdown
 
         self.clo = CLO()
 
@@ -79,12 +82,26 @@ class Dorothy(object):
     def prelaunch(self, val):
         self._prelaunch = val
 
-    def shutdown(self, sig, frame):
+    @property
+    def shutdown(self):
+        return self._shutdown_cb
+
+    @shutdown.setter
+    def shutdown(self, val):
+        self._shutdown_cb = val
+
+    def _shutdown(self, sig, frame):
         settings.log.info('Stopping the server')
-        self.server.stop()
+
         if not self.clo.options.debug:
             # give current connection 2 seconds to finish up but no in debug
-            time.sleep(2)
+            time.sleep(self.clo.options.timeout)
+
+        if self.shutdown:
+            settings.io_loop.add_callback_from_signal(self.shutdown)
+            time.sleep(self.clo.options.timeout)
+
+        self.server.stop()
         settings.io_loop.stop()
 
     def run(self, **kwargs):
@@ -97,9 +114,9 @@ class Dorothy(object):
         self.server = tornado.httpserver.HTTPServer(application, xheaders=True)
         self.server.listen(self.clo.options.port)
 
-        signal.signal(signal.SIGINT, self.shutdown)
-        signal.signal(signal.SIGTERM, self.shutdown)
-        signal.signal(signal.SIGQUIT, self.shutdown)
+        signal.signal(signal.SIGINT, self._shutdown)
+        signal.signal(signal.SIGTERM, self._shutdown)
+        signal.signal(signal.SIGQUIT, self._shutdown)
 
         settings.io_loop = tornado.ioloop.IOLoop.instance()
 
