@@ -7,8 +7,12 @@ class ApiError(Exception):
         self.message = message
 
     def __str__(self):
-        return xjson.dumps(dict(code=self.code, message=self.message))
+        return xjson.dumps(dict(code=self.code, error=self.message))
 
 
 class SettingsError(Exception):
+    pass
+
+
+class NotFoundError(Exception):
     pass
\ No newline at end of file
