@@ -1,11 +1,14 @@
 import bson
 import json
+from datetime import datetime
 
 
 class CusEncoder(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, bson.ObjectId):
             return str(obj)
+        if isinstance(obj, datetime):
+            return obj.isoformat()
         return json.JSONEncoder.default(self, obj)
 
 
